---
title: Tech principles
---

@## Developer contract

Контракт с разработчиком — это некий список правил и ожиданий, который мы даем вам. Когда я говорю про контракт, я говорю про нейминг, поведение компонентов, среднее количество багов, релизы, бета-версии, обещание что-то сделать и так далее. Этот контракт также дает некий процесс самообучения. Вы, используя наши компоненты, сами понимаете его. Мы же со своей стороны стремимся не нарушать и соблюдать наши правила.

> API, который вы не можете запомнить, — плохой API 🤭

@## Customize

Мы стараемся проектировать компоненты, так, чтобы они умели делать все, что от них требуется и что укладывается в их нормальное использование. По умолчанию поведение описанное в ux-гайде является основным, но мы стараемся давать возможность для любых манипуляций, чтобы можно было решить любую проблему, даже ту, о которой мы пока ещё не знаем. Далее будут описаны решения, которых мы придерживаемся для решения проблемы кастомизации.

Важно понимать, чем сильнее вы хотите изменить компонент от его дефолтного состояния, тем глубже вы будите погружаться в наш API и внутреннюю реализацию.

@## DOM node

Все наши компоненты в ref-e возвращают dom-ноду, это сделано специально.

Во-первых, вы всегда можете её получить для интеграций с другими библиотеками.

Во-вторых, это убирает дополнительные свойства вида `inputRef`, `rootRef` и так далее.

В-третьих, отдавать инстанс класса — плохая практика, так как это раскрывает внутреннюю реализацию.

@## Root tag

Практически у каждого компонента есть свой html-tag, в который он рендериться. Мы называем его root tag.

Мы даем возможность его подменить. Например, чтобы превратить кнопку в ссылку, не создавая обертку.

Кроме обычных html-тегов, вы можете передать другой react-компонент, — это поможет вам подменить рендер и расширять компоненты друг от друга, не создавая дополнительную DOM-ноду. При этом все свойства буду сквозить дальше, на переданный тег.

@## Inner state

Мы разрабатываем свои компоненты так, чтобы в них не было стейта и все состояния задавались снаружи. Это позволяет нам убедиться в том, что контроль состоянием и его изменение остается у вас.

У каждого свойства, которое может меняться, будет хендлер. Например, `visible` — это свойство, которое вы задаёте на компоненте; `onVisibleChange` — это хендлер, на который вы подписываетесь и который будет вызван с новым значением `visible`.

Вы могли видеть такую логику у нативного инпута: когда вы контролируете `value`, и `onChange` является как бы запросом на изменения, а менять value или нет — решать вам.

Хендлеры таких свойств имеют определённую нотацию. К началу их имени добавляется on, а в конце — Change.

@## Uncontrolled props

Исходя из вышесказанного, чтобы компонент полностью функционировал в режиме по умолчанию, вам нужно будет передать в него все его свойства и подписаться на все его хендлеры.
Это не всегда удобно, так как свойств может быть много и свою логику изменения свойств в хендлерах не всегда нужно писать.

Чтобы решить эту проблему, мы сделали возможным делать свойства неконтролируемыми. То есть, если вы не передаёте в компонент значение, то он будет использовать свой внутренний стейт, который будет меняться при вызове хендлеров.

Опять же, вы могли видеть этот подход в обычном инпуте: если вы не передадите в него `value`, то пользователь все ещё сможет в него печатать. Значение `value` теперь будет меняться внутри инпута, а не задаваться снаружи.

Таким образом, все наши компоненты по умолчанию работают без определения каких-либо свойств или хендлеров.

@## Default props

Все свойства могут работать в двух режимах: контролируемом (вы передаёте props) и неконтролируемом (на внутреннем state).
При втором варианте начальное состояние зашито внутри, но мы даём возможность его поменять, не делая компонент контролируемым.

У всех свойств, которые могут меняться, есть начальное состояние, которое находится в свойстве default + название свойства, и его можно поменять, передав другое значение. Например, у тултипа есть свойство `visible` и по умолчанию он закрыто. И если мы хотим, чтобы его начальное состояние было открыто, то мы можем передать `defaultVisible=true`.

Такое же поведение есть у нативного инпута, когда вам надо задать начальное значение, но вы не хотите им управлять и делать компонент контролируемым.

> Важно понимать, что default свойства отрабатывают только в момент инициализации компонента и не участвуют в последующих апдейтах, так что дальнейшие изменение этого свойства ни к чему не приведёт.

@## No props API overload

Для того чтобы безопасно расширять и гарантировать предсказуемое поведение, все компоненты НЕ глушат переданные им свойства.

Это значит, что если вы передаете какое-то свойство, оно обязательно будет применяться в том или ином виде, даже если это сломает компонент.
Свойства должны расширяться: классы и стили объединяются, ref распространяются дальше, callbackHandler встают в очередь друг за другом и вызываются по порядку.

При одинаковых ключах мы отдаём приоритет свойствам пользователя.
Хендлер пользователя также будет вызван первым в стеке вызовов.

@## Cancel handler

Мы уже умеем управлять отображением, передавая свой компонент и подменяя рендер.
Также мы умеем управлять состоянием компонента, подписываясь и применяя его свойства так, как мы захотим.
Но в сложных компонентах есть ещё логика, которой мы пока что не умеем манипулировать.
Это цепочки обработчиков и реакция на обработчики.

Например, в Select-е `onClick` вызовет onChange, который вызовет `onVisibleChange`.
Или на `onKeyDown`(ESC) сбрасывается фокус, и срабатывает `onBlur`.

Эта логика зашита в компоненте и не является его состоянием.
Мы должны уметь внедрятся в эти цепочки для гарантии того, что мы можем максимально настраивать компоненты, как его внешний вид, так и логику работы.

Для прерывания цепочек событий мы должны вернуть из обработчика `false`.
Это работает из-за очереди вызовов (см. пункт 6).
То есть если у нас внутри есть хендлер `onClick,` и вы навешивание свой`onClick`, то сначала вызовется ваш, потом произойдёт проверка на возвращаемые значение, и, если оно не `false`, то вызовется наш.
Эта возможность даёт отменять все наши обработчики.

@## Static children

Когда у нас сложный компонент, который внутри состоит из нескольких компонентов или хотя бы html-элементов, то встаёт вопрос, как распространять свойства на эти компоненты.
Мы стремимся дать возможность доступа к каждому элементу внутри компонента.

Для этого мы делаем такие элементы как статичные поля класса родителя.
Выглядит это так: есть `<Button/>`, а внутри есть `<Button.Text/>` и `<Button.Addon/>`.
Вы имеете полный доступ ко всем элементам кнопки и можете навешивать любые свойства на них.

Такой подход довольно многословный для тех, кому не нужен доступ к внутренностям. Поэтому мы стараемся заполнять children по умолчанию в каждом компоненте, чтобы вы могли просто вставить компонент, не разворачивая его.

@## Context in component

В любом компоненте можно изменять порядок и расположение элементов внутри него.
Это накладывает сложности с передачей свойств от родителя к детям. Например, Select-у нужно навесить `onClick` на Option.

Для решения этой проблемы мы используем реактовый контекст, тем самым полностью освобождаем рендер.
Свойства, которые распространяются на дочерние компоненты, лежат в getter-функциях внутри контекста.

Например, если Select что-то передаёт в Option, то эти свойства можно получить из функции `getOptionProps()`, которая находится в контексте Select-а.
При вызове функции можно передать свои свойства, и они будут слиты со свойствами для компонента.
Далее мы объясним, как получить контекст и зачем это может пригодится.

@## Function children

В любой компонент можно положить функцию и она будет вызвана, а результат вставлен в DOM.
Также первым аргументом в функцию придёт объект, в котором будут все состояния компонента, все его свойства и getter-функции для детей.

Это может понадобиться в двух случаях:

1. Вам нужно состояние компонента, но вы не хотите делать его контролируемым.
2. Вы хотите заменить дочерние компоненты на свои, для этого вы используете getter-функции.
